# Bowtie

[![Documentation Status](https://readthedocs.org/projects/bowtie-py/badge/?version=latest)](http://bowtie-py.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/jwkvam/bowtie.svg?branch=master)](https://travis-ci.org/jwkvam/bowtie)
[![PyPI version](https://badge.fury.io/py/bowtie.svg)](https://badge.fury.io/py/bowtie)
[![PyPI](https://img.shields.io/pypi/pyversions/bowtie.svg)](https://pypi.python.org/pypi/bowtie/)
[![codecov](https://codecov.io/gh/jwkvam/bowtie/branch/master/graph/badge.svg)](https://codecov.io/gh/jwkvam/bowtie)

![Demo](https://cloud.githubusercontent.com/assets/86304/20045988/69e5678a-a45a-11e6-853b-7f60a615c9da.gif)

## Introduction

Bowtie is a library for writing dashboards in Python.
No need to know web frameworks or JavaScript, focus on building functionality in Python.
Interactively explore your data in new ways!
Deploy and share with others!

## Demo

See a live [example](https://bowtie-demo.herokuapp.com/) generated from this [code](https://github.com/jwkvam/bowtie-demo/blob/master/example.py)!

## Documentation

Available [here](http://bowtie-py.readthedocs.io/en/latest/).

## Install

```
pip install bowtie
```

## Requirements

Install [node](https://nodejs.org/en/) and install `webpack` and `yarn` globally.

```
npm install -g webpack yarn
```

## The Goal

![@astrobiased @treycausey @vagabondjack the lack of a comprehensive production-grade Shiny-alike for Python is a Big Problem](https://cloud.githubusercontent.com/assets/86304/18606859/8ced55a6-7c70-11e6-8b5e-fba0ffcd78da.png)

## Gallery

Check out the [gallery](https://github.com/jwkvam/bowtie/wiki/Gallery) and feel free to add your own creations!

## Contributing

You can help Bowtie in many ways including:
- Trying it [out](http://bowtie-py.readthedocs.io/en/latest/quickstart.html) and reporting bugs or simply what was difficult to use or get working.
- Helping improve the [documentation](https://github.com/jwkvam/bowtie/tree/master/doc).
- Writing new [widgets](http://bowtie-py.readthedocs.io/en/latest/newcomponents.html).
- Say [thanks](https://saythanks.io/to/jwkvam)!
